@@ -1,3 +1,31 @@
+//
+// Copyright (c) 2009-2011, ERICSSON AB
+// All rights reserved.
+// 
+// Redistribution and use in source and binary forms, with or without
+// modification, are permitted provided that the following conditions are met:
+// 
+//     * Redistributions of source code must retain the above copyright notice, 
+//       this list of conditions and the following disclaimer.
+//     * Redistributions in binary form must reproduce the above copyright
+//       notice, this list of conditions and the following disclaimer in the
+//       documentation and/or other materials provided with the distribution.
+//     * Neither the name of the ERICSSON AB nor the names of its contributors
+//       may be used to endorse or promote products derived from this software
+//       without specific prior written permission.
+// 
+// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
+// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
+// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+//
+
 #include "feldspar_c99.h"
 
 #include <stdint.h>
@@ -14,6 +42,7 @@
 #endif /* WIN32 */
 
 
+unsigned int feldspar_c99_linker_hook = 0xDECAFBAD;
 
 /*--------------------------------------------------------------------------*
  *                 pow(), abs(), signum(), logBase()                        *
@@ -1708,7 +1737,7 @@ void elapsedTimeString( char* str )
         tv.tv_sec = tv.tv_sec - trace_start_time.tv_sec - 1;
         tv.tv_usec = 1000000 + tv.tv_usec - trace_start_time.tv_usec;
     }
-    sprintf(str, "%ld.%06ld", tv.tv_sec, tv.tv_usec);
+    sprintf(str, "%ld.%06d", tv.tv_sec, (int)tv.tv_usec);
 }
 
 #endif /* WIN32 */
